package com.example.chat.controller.websocket;

import com.alibaba.fastjson.JSON;
import com.example.chat.dao.chat.ChatMapper;
import com.example.chat.dao.chat.ChatMessage;
import com.example.chat.entity.chat.Message;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.CrossOrigin;

import javax.websocket.*;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

@CrossOrigin
@Slf4j
@ServerEndpoint(value = "/chat/get")
@Component
public class WebSocketServer {

    private static final List<Session> sessionList = new CopyOnWriteArrayList<>();


    public ChatMapper chatMapper=new ChatMessage();

    @OnOpen
    public void onOpen(Session session) throws IOException {
        sessionList.add(session);
        log.info("有新用户加入聊天，当前在线人数为{}", sessionList.size());
        if (chatMapper == null) {
            log.error("chatMapper为null");
        }
        List<Message> messageList = chatMapper.getMessage();
        sendAllSession(messageList);
    }

    @OnMessage
    public void onMessage(String message) throws IOException {
        ObjectMapper objectMapper=new ObjectMapper();

        Message message1 = objectMapper.readValue(message,Message.class);
        log.info("Message+{}",message1);
        log.info("webMessage{}",message);
        chatMapper.addMessage(message1);
        List<Message> messageList = chatMapper.getMessage();
        sendAllSession(messageList);
    }

    @OnError
    public void onError(Throwable error) {
        log.error("发生错误");
        error.printStackTrace();
    }

    @OnClose
    public void onClose(Session session) {
        log.info("有一个用户断开连接了");
        sessionList.remove(session);
    }

    /*
     * 发消息给客户端
     * */
    public void sendAllSession(List<Message> message){

        try {
            for (Session session : sessionList) {
                log.info("给客户端发送消息{}", session);
                session.getBasicRemote().sendText(JSON.toJSONString(message));
            }
        } catch (Exception e) {
            log.error("消息发送失败", e);
        }

    }


}
