package com.example.chat.jwt;

import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.CorsRegistry;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import java.util.ArrayList;

@Configuration
public class InterceptorConfig implements WebMvcConfigurer {
    TokenInterceptor tokenInterceptor;

    public InterceptorConfig(TokenInterceptor tokenInterceptor) {//构造函数
        this.tokenInterceptor = tokenInterceptor;
    }

    @Override
    public void addInterceptors(InterceptorRegistry registry) {//配置拦截器
        System.out.println("拦截器被配置了");
        ArrayList<String> excludePath = new ArrayList<>();
        excludePath.add("/login");//登录
        excludePath.add("/checkCode");
        excludePath.add("/sendCode");
        excludePath.add("/register");//注册
        excludePath.add("/register");
        excludePath.add("/chat/get");
        registry.addInterceptor(tokenInterceptor)//注册拦截器
                .addPathPatterns("/**")//拦截所有请求
                .excludePathPatterns(excludePath);//添加拦截白名单
        WebMvcConfigurer.super.addInterceptors(registry);//调用父接口
    }

    @Override
    public void addCorsMappings(CorsRegistry registry) {
        registry.addMapping("/**").allowCredentials(true)//允许携带cookie
                .allowedMethods("GET", "POST", "DELETE", "PUT", "PATCH", "OPTIONS", "HEAD")//允许访问的方法
                .allowedOriginPatterns("*")//允许的跨域访问地址
                .maxAge(3600 * 24);//options缓存时间
    }
}
